"""
Defines interfaces exposed to library user
"""
from membank.interface import LoadMemory
from membank.errors import *
